@@ -8,13 +8,13 @@ import collections
 VersionInfo = collections.namedtuple('VersionInfo', ('major', 'minor', 'micro'))
 __version_info__ = VersionInfo(
     major=1,
-    minor=2,
-    micro=8,
+    minor=4,
+    micro=1,
 )
 __version__ = '.'.join(str(val) for val in __version_info__)
-__author__ = u'Michael Stroeder'
-__mail__ = u'michael@stroeder.com'
-__copyright__ = u'(C) 2017-2021 by Michael Ströder <michael@stroeder.com>'
+__author__ = 'Michael Stroeder'
+__mail__ = 'michael@stroeder.com'
+__copyright__ = '(C) 2017-2021 by Michael Ströder <michael@stroeder.com>'
 __license__ = 'Apache-2.0'
 
 __all__ = [
