@@ -11,7 +11,6 @@ from uuid import UUID
 # Imports from pyasn1
 from pyasn1.type import namedtype, namedval, univ, tag, constraint
 from pyasn1.codec.ber import encoder, decoder
-from pyasn1_modules.rfc2251 import LDAPString
 
 from . import RequestControl, ResponseControl, KNOWN_RESPONSE_CONTROLS
 from ..extop import IntermediateResponse, INTERMEDIATE_RESPONSE_REGISTRY
@@ -375,7 +374,7 @@ class SyncInfoRefreshDelete(SyncInfoMessage):
         component = self.syncinfo.getComponent()
         self.cookie = None
         cookie = component['cookie']
-        if cookie is not univ.noValue:
+        if cookie.isValue:
             self.cookie = bytes(cookie)
         self.refreshDone = bool(component['refreshDone'])
 
@@ -396,7 +395,7 @@ class SyncInfoRefreshPresent(SyncInfoMessage):
         component = self.syncinfo.getComponent()
         self.cookie = None
         cookie = component['cookie']
-        if cookie is not univ.noValue:
+        if cookie.isValue:
             self.cookie = bytes(cookie)
         self.refreshDone = bool(component['refreshDone'])
 
@@ -418,7 +417,7 @@ class SyncInfoIDSet(SyncInfoMessage):
         component = self.syncinfo.getComponent()
         self.cookie = None
         cookie = component['cookie']
-        if cookie is not univ.noValue:
+        if cookie.isValue:
             self.cookie = bytes(cookie)
         self.refreshDeletes = bool(component['refreshDeletes'])
 
@@ -433,7 +432,7 @@ class SyncInfoIDSet(SyncInfoMessage):
             self.__class__.__name__,
             self.cookie,
             self.refreshDeletes,
-            self.uuids,
+            self.syncUUIDs,
         )
 
 
