@@ -78,7 +78,10 @@ class DNObj(tuple):
             return cls([])
         return cls([
             tuple([
-                (at_sanitizer(at.decode('ascii')), av.decode(cls.encoding))
+                (
+                    at_sanitizer(at.decode('ascii')),
+                    (None if av is None else av.decode(cls.encoding))
+                )
                 for at, av, _ in dn_comp
             ])
             for dn_comp in _libldap0_function_call(_libldap0.str2dn, dn.encode(cls.encoding), flags)
@@ -117,14 +120,22 @@ class DNObj(tuple):
         res = isinstance(other, self.__class__) and len(self) == len(other)
         i = 0
         while res and i < len(self):
-            res = len(self[i]) == len(other[i])
+            if len(self[i]) != len(other[i]):
+                res = False
+                break
             j = 0
+            other_dict = {
+                at.lower(): av
+                for at, av in other[i]
+            }
             while res and j < len(self[i]):
-                res = (
-                    self[i][j][0].lower() == other[i][j][0].lower()
-                    and
-                    self[i][j][1] == other[i][j][1]
-                )
+                at_lower = self[i][j][0].lower()
+                try:
+                    other_val = other_dict[at_lower]
+                except KeyError:
+                    res = False
+                else:
+                    res = self[i][j][1] == other_dict[at_lower]
                 j += 1
             i += 1
         return res
