@@ -17,7 +17,7 @@ from .err import \
     PasswordPolicyExpirationWarning, \
     PasswordPolicyExpiredError
 from . import LIBLDAP_TLS_PACKAGE
-from ldap0.controls.simple import AuthorizationIdentityResponseControl
+from .controls.simple import AuthorizationIdentityResponseControl
 from .err import NoUniqueEntry
 from .base import encode_list
 from .dn import DNObj
@@ -119,9 +119,13 @@ class LDAPObject:
         self._cache_ttl = cache_ttl
         self._cache = Cache(ttl=cache_ttl)
         self.flush_cache()
+        # Do not restart connections
         self.set_option(_libldap0.OPT_RESTART, False)
-        self.set_option(_libldap0.OPT_DEREF, False)
+        # Switch off automatic alias dereferencing
+        self.set_option(_libldap0.OPT_DEREF, _libldap0.DEREF_NEVER)
+        # Switch off automatic referral chasing
         self.set_option(_libldap0.OPT_REFERRALS, False)
+        # always require full TLS server validation
         self.set_option(_libldap0.OPT_X_TLS_REQUIRE_CERT, _libldap0.OPT_X_TLS_HARD)
 
     @property
@@ -1155,12 +1159,12 @@ class LDAPObject:
                 cache_ttl=cache_ttl,
             ))
         except _libldap0.SIZELIMIT_EXCEEDED:
-            raise NoUniqueEntry('Size limit exceeded for %r ()' % (filterstr))
+            raise NoUniqueEntry('Size limit exceeded for %r' % (filterstr,))
         # strip search continuations
         ldap_res = [res for res in ldap_res if isinstance(res, SearchResultEntry)]
         # now check again for length
         if not ldap_res:
-            raise NoUniqueEntry('No search result for %r' % (filterstr))
+            raise NoUniqueEntry('No search result for %r' % (filterstr,))
         if len(ldap_res) > 1:
             raise NoUniqueEntry(
                 'Non-unique search results (%d) for %r' % (len(ldap_res), filterstr)
